@@ -586,7 +586,7 @@ class Bitpin:
         }
 
         if order_id:
-            json_data['order_id'] = order_id
+            json_data['identifier'] = order_id
 
         response = self._request(
             f_name,
@@ -645,7 +645,7 @@ class Bitpin:
 
         return self._process_response(f_name, response, f_args)
 
-    def recent_trades(self, market_id: t.Optional[int]):
+    def recent_trades(self, market_id: t.Optional[int] = None) -> t.Dict:
         """
         Get recent trades.
 
@@ -668,16 +668,16 @@ class Bitpin:
             auth=True,
         )
 
-        processed_reponse = self._process_response(f_name, response, f_args)
+        processed_response = self._process_response(f_name, response, f_args)
 
         if market_id is not None:
-            filtered_results = [r for r in processed_reponse.get('results') if r['market']['id'] == market_id]
+            filtered_results = [r for r in processed_response.get('results') if r['market']['id'] == market_id]
 
-            processed_reponse['results'] = filtered_results
+            processed_response['results'] = filtered_results
             
-        return processed_reponse
+        return processed_response
 
-    def balances(self, currency_id: t.Optional[int]):
+    def balances(self, currency_id: t.Optional[int] = None) -> t.Dict:
         """
         Get balances.
 
@@ -700,16 +700,16 @@ class Bitpin:
             auth=True,
         )
 
-        processed_reponse = self._process_response(f_name, response, f_args)
+        processed_response = self._process_response(f_name, response, f_args)
 
         if currency_id is not None:
-            filtered_results = [r for r in processed_reponse.get('results') if r['currency']['id'] == currency_id]
+            filtered_results = [r for r in processed_response.get('results') if r['currency']['id'] == currency_id]
 
-            processed_reponse['results'] = filtered_results
+            processed_response['results'] = filtered_results
             
-        return processed_reponse
+        return processed_response
 
-    def open_orders(self, market_id: t.Optional[int]):
+    def open_orders(self, market_id: t.Optional[int] = None) -> t.Dict:
         """
         Get open orders.
 
@@ -732,13 +732,13 @@ class Bitpin:
             auth=True,
         )
 
-        processed_reponse = self._process_response(f_name, response, f_args)
+        processed_response = self._process_response(f_name, response, f_args)
 
         if market_id is not None:
-            filtered_results = [r for r in processed_reponse.get('results') if r['market']['id'] == market_id]
+            filtered_results = [r for r in processed_response.get('results') if r['market']['id'] == market_id]
 
-            processed_reponse['results'] = filtered_results
+            processed_response['results'] = filtered_results
             
-        return processed_reponse
+        return processed_response
 
 
